Index: pkg/dartino_agent/tool/client.dart |
diff --git a/pkg/fletch_agent/tool/client.dart b/pkg/dartino_agent/tool/client.dart |
similarity index 87% |
rename from pkg/fletch_agent/tool/client.dart |
rename to pkg/dartino_agent/tool/client.dart |
index 235fcfef9dfcc5a882fa6baf9c46afacabdb8138..c8acdec74b873f1633b95bd3ae99c62d9fff8368 100644 |
--- a/pkg/fletch_agent/tool/client.dart |
+++ b/pkg/dartino_agent/tool/client.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-library fletch_agent.client; |
+library dartino_agent.client; |
import 'dart:io'; |
import 'dart:typed_data'; |
@@ -13,11 +13,11 @@ import '../lib/agent_connection.dart'; |
void printUsage() { |
print(''' |
Usage: |
-The Fletch agent command line client supports the following flags: |
+The Dartino agent command line client supports the following flags: |
--port: the port on which to connect, default: 12121 |
--host: the ip address on which to connect, default: 127.0.0.1 |
- --cmd: the command to send to the Fletch agent, default: 0 (START_VM) |
+ --cmd: the command to send to the Dartino agent, default: 0 (START_VM) |
--pid: the pid of the vm to stop, only used when --cmd=1 (STOP_VM) |
--signal: which signal to send to the vm. Requires the --pid option to |
be specified |
@@ -28,7 +28,7 @@ Example: Get the version of the agent running on 192.168.1.1: |
exit(1); |
} |
/// Small dart program to issue commands to the fletch agent. |
void main(List<String> arguments) async { |
// Startup the agent listening on specified port. |
int port = 12121; |
@@ -103,7 +103,7 @@ void main(List<String> arguments) async { |
try { |
socket = await Socket.connect(host, port); |
} on SocketException catch (error) { |
- print('Could not connect to Fletch Agent on \'$host:$port\'. ' |
+ print('Could not connect to Dartino Agent on \'$host:$port\'. ' |
'Received error: $error'); |
printUsage(); |
} |
@@ -132,9 +132,9 @@ void main(List<String> arguments) async { |
} |
Uri packageUri = new Uri.file(packageFile); |
List<String> nameParts = packageUri.pathSegments.last.split('_'); |
- if (nameParts.length != 3 || nameParts[0] != 'fletch-agent') { |
- print('A fletch-agent package must have a name of the form\n' |
- ' fletch-agent_<version>_<platform>'); |
+ if (nameParts.length != 3 || nameParts[0] != 'dartino-agent') { |
+ print('A dartino-agent package must have a name of the form\n' |
+ ' dartino-agent_<version>_<platform>'); |
exit(1); |
} |
String version = nameParts[1]; |
@@ -144,9 +144,9 @@ void main(List<String> arguments) async { |
await connection.upgradeAgent(version, data); |
print('Update finished'); |
break; |
- case RequestHeader.FLETCH_VERSION: |
- String version = await connection.fletchVersion(); |
- print('Fletch Agent Version $version'); |
+ case RequestHeader.DARTINO_VERSION: |
+ String version = await connection.dartinoVersion(); |
+ print('Dartino Agent Version $version'); |
break; |
case RequestHeader.SIGNAL_VM: |
if (pid == null) { |
@@ -28,7 +28,7 @@ Example: Get the version of the agent running on 192.168.1.1: |
exit(1); |
} |
-/// Small dart program to issue commands to the fletch agent. |
+/// Small dart program to issue commands to the dartino agent. |
void main(List<String> arguments) async { |
// Startup the agent listening on specified port. |